/**
 * Copyright (c) 2012 EBMWebsourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes.key;

import java.util.Arrays;
import java.util.Objects;

import org.ow2.petals.probes.api.enums.ExecutionStatus;
import org.ow2.petals.probes.api.key.ExecutionStatusProbeKey;
import org.ow2.petals.probes.api.key.ProbeKey;
import org.ow2.petals.probes.api.key.StringArrayProbeKey;

/**
 * Implementation of a key needed by keyed probes including execution as
 * grouping criteria. It's a wrapper of a key implementing {@link ProbeKey} and
 * an execution status.
 * 
 * @author Christophe DENEUX (PetalsLink)
 * 
 * @param <K>
 *            Type of the initial key grouping values, implementing
 *            {@link ProbeKey}.
 */
public class ExecutionStatusProbeKeyImpl<K extends ProbeKey> extends StringArrayProbeKey
        implements ExecutionStatusProbeKey<K> {
    /**
     * The key implementing {@link ProbeKey}
     */
    final private K key;

    /**
     * Execution status
     */
    private ExecutionStatus executionStatus;

    public ExecutionStatusProbeKeyImpl(final K key, final ExecutionStatus executionStatus) {
        super(buildStringArray(key, executionStatus));
        this.key = key;
        this.executionStatus = executionStatus;
    }

    private static <K extends ProbeKey> String[] buildStringArray(final K key, final ExecutionStatus executionStatus) {
        final String[] keyArray = key.toStringArray();
        final String[] res = Arrays.copyOf(keyArray, keyArray.length + 1);
        res[keyArray.length] = Objects.toString(executionStatus);
        return res;
    }

    @Override
    public K getOriginalKey() {
        return this.key;
    }

    @Override
    public ExecutionStatus getExecutionStatus() {
        return this.executionStatus;
    }
}